// testcolors demo for Adafruit RGBmatrixPanel library.
// Renders 512 colors on our 16x32 RGB LED matrix:
// http://www.adafruit.com/products/420
// Library supports 4096 colors, but there aren't that many pixels!  :)

// Written by Limor Fried/Ladyada & Phil Burgess/PaintYourDragon
// for Adafruit Industries.
// BSD license, all text above must be included in any redistribution.

#include <RGBmatrixPanel.h>

// Most of the signal pins are configurable, but the CLK pin has some
// special constraints.  On 8-bit AVR boards it must be on PORTB...
// Pin 8 works on the Arduino Uno & compatibles (e.g. Adafruit Metro),
// Pin 11 works on the Arduino Mega.  On 32-bit SAMD boards it must be
// on the same PORT as the RGB data pins (D2-D7)...
// Pin 8 works on the Adafruit Metro M0 or Arduino Zero,
// Pin A4 works on the Adafruit Metro M4 (if using the Adafruit RGB
// Matrix Shield, cut trace between CLK pads and run a wire to A4).

#define CLK  8   // USE THIS ON ARDUINO UNO, ADAFRUIT METRO M0, etc.
//#define CLK A4 // USE THIS ON METRO M4 (not M0)
//#define CLK 11 // USE THIS ON ARDUINO MEGA
#define OE   9
#define LAT 10
#define A   A0
#define B   A1
#define C   A2

RGBmatrixPanel matrix(A, B, C, CLK, LAT, OE, false);

int highThreshold=40;   //turn on timer
int lowThreshold=20;    // turn off timer
int timerOn=0;
int sensorPin = A4;    // select the input pin for the potentiometer
int buzzer = A5;
int buzzerTime = 95;
int sensorValue = 0;  // variable to store the value coming from the sensor
int pressure = 0;      //pressure value
int d=15;   //delay in seconds
unsigned long c=0;  //cycle count
unsigned long s=0;   //seconds (calculated)
unsigned long m=0;  // minutes (calcualted)

void setup() {
  Serial.begin(9600);
  matrix.begin();
  pinMode(LED_BUILTIN, OUTPUT); //built in LED lights
  pinMode(buzzer, OUTPUT);
}

void loop() {
  // read the value from the sensor:
  sensorValue = analogRead(sensorPin);
  pressure =  (sensorValue-100)/8.1;    //calibrate pressure reading
  
  if(pressure<3){   //if the sensor drifts a little then we don't want the pressure to read 1 when it should read 0
    pressure = 0;
  }

  if(pressure>=highThreshold){    //start the c counter once the pressure goes over the high threshold
    timerOn=1;
  }

  if(timerOn==1){    //if the timer should be on, c up 1 every loop cycle
    c=c+1;
    digitalWrite(LED_BUILTIN, HIGH);  // turn on built in LED
  }
  
  if(pressure<=lowThreshold){   //once pressure goes below the low threshold
    c=0;                        // reset counter
    timerOn=0;                  // turn timer off
    digitalWrite(LED_BUILTIN, LOW); //turn off built in LED
  }
  m=c/(60/d);   //calculate minutes from counter and delay
  s=c*d-m*60;     // calculate seconds from counter, minutes, and delay

  if(m>buzzerTime){         // turn on buzzer if over 95 minutes
    tone(buzzer, 1000); // Send 1KHz sound signal...
  }
  else {
    noTone(buzzer);     // Stop sound...
  }

  // draw some onto the display
  matrix.setCursor(1, 0);  // start at top left, with one pixel of spacing
  matrix.setTextSize(1);   // size 1 == 8 pixels high
  matrix.fillScreen(matrix.Color333(0,0,0));
  matrix.setTextColor(matrix.Color333(0,7,0));
  if(m>59){         // change color to yelow if over 59 mins
    matrix.setTextColor(matrix.Color333(7,7,0));
  }
  if(m>89){         //change color to red if over 89 mins
    matrix.setTextColor(matrix.Color333(7,0,0));
  }
  
  matrix.print('P');
  matrix.print(' ');
  matrix.print(pressure);
  
  matrix.setCursor(1, 9);  // next line
  matrix.print('T');
  matrix.print(' ');
  matrix.print(m);
  delay(d*1000);


  Serial.print("Sensor Value = ");  //report various information to serial monitor
  Serial.print(sensorValue);
  
  Serial.print("; Pressure = ");
  if(sensorValue<100){
    Serial.print(" ");
  }
  Serial.print(pressure);
  
  Serial.print("; T = ");
  if(m<10){
    Serial.print(" ");
  }
  if(m<100){
    Serial.print(" ");
  }
  Serial.print(m); 
  Serial.print(":"); 
  if(s<10){
    Serial.print("0");
  }
  Serial.print(s); 
  Serial.print("; c = ");
  Serial.println(c);


}
